Welcome to behave!
==================

.. pypi-release:: behave
   :prefix: Download
   :class: note

behave is behaviour-driven development, Python style.

Behavior-driven development (or BDD) is an agile software development
technique that encourages collaboration between developers, QA and
non-technical or business participants in a software project. We have
a page further describing this :doc:`philosophy <philosophy>`.

:pypi:`behave` uses tests written in a natural language style,
backed up by Python code.

Once you've :doc:`installed <install>` *behave*, we recommend reading the

  * :doc:`tutorial <tutorial>` first and then
  * :doc:`feature test setup <gherkin>`,
  * :doc:`behave API <api>` and
  * :doc:`related software <related>` (things that you can combine with :pypi:`behave`)
  * finally: :doc:`how to use and configure <behave>` the :pypi:`behave` tool.

There is also a :doc:`comparison <comparison>` with the other tools available.

Contents
--------

.. toctree::
   :maxdepth: 2

   install
   tutorial
   philosophy
   gherkin
   behave
   api
   django
   comparison
   new_and_noteworthy
   appendix


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

